
Changelog
=========

1.1.0-alpha (2020-11-01)
------------------------
* Alpha release that supports poster mode. 
* Has not been tested because wikis have been frozen.
* Use at your own risk!

1.0.0 (2020-10-27)
------------------
* iGEM Judging Release!

0.0.15 (2020-10-21)
-------------------
* Bug fixes

0.0.14 (2020-10-21)
-------------------
* Support srcset

0.0.13 (2020-08-27)
-------------------
* Bug fixes

0.0.6 (2020-08-02)
------------------
* Allow silencing warnings
* Add WikiSync to upload description

0.0.5 (2020-07-30)
------------------

* Check file size before uploading
* Don't change URL if file not found
* Add year configuration option
* Enforce asset paths to start with 'assets/'
* Improve logging and change log and cookie filenames
* Classify logging messages
* Refactor upload_map
* Don't rename files if they already follow iGEM spec
* Check for filename too large
* Print summary after execution

0.0.4 (2020-07-25)
------------------

* Drop jsmin.
* Add version specifiers to dependencies.

0.0.3 (2020-07-25)
------------------

* Ensures that directories exist before writing files.

0.0.2 (2020-07-25)
------------------

* Assets are also written to disk in build_dir.

0.0.1 (2020-07-25)
------------------

* Build directory doesn't get cleared on every run.

0.0.0 (2020-07-25)
------------------

* First release on PyPI.
